# Find commit and version via redirection on https://www.chiark.greenend.org.uk/~sgtatham/puzzles/puzzles.tar.gz
%define commit  79a5378
%define uname   puzzles

Name:           sgt-%{uname}
Version:        20191231
Release:        %mkrel 2
Summary:        Simon Tatham's one-player puzzle collection
Group:          Games/Puzzles
License:        MIT
URL:            https://www.chiark.greenend.org.uk/~sgtatham/puzzles/
Source0:        https://www.chiark.greenend.org.uk/~sgtatham/puzzles/%{uname}-%{version}.%{commit}.tar.gz
Source1:        template.desktop

BuildRequires:  pkgconfig(gtk+-3.0)

%description
This is a collection of small desktop toys, little games that you can
pop up in a window and play for two or three minutes while you take a
break from whatever else you were doing.

%prep
%autosetup -p1 -n %{uname}-%{version}.%{commit}

%build
autoreconf -vfi
%configure --bindir=%{_gamesbindir}
%make_build

%install
%make_install
install -d %{buildroot}%{_datadir}/applications

# Rename binaries, install icons and create desktop files
path=%{buildroot}%{_gamesbindir}
for game in ${path}/*; do
    base=`basename ${game}`
    name=`perl -e 'print ucfirst($ARGV[0])' "${base}"`
    command=puzzle-${base}

    mv ${game} ${path}/puzzle-${base}

    sed -e "s/<NAME>/${name}/g;s!<EXEC>!${command}!g;s!<ICON>!${command}!g" %{_sourcedir}/template.desktop > puzzle-${base}.desktop
    desktop-file-install --dir=%{buildroot}%{_datadir}/applications/ ${command}.desktop

    for size in 16 32 48; do
        install -D -m644 icons/${base}-${size}d24.png %{buildroot}%{_iconsdir}/hicolor/${size}x${size}/apps/${command}.png
    done
done

# Create a menu subfolder for Simon Tatham's puzzles in the Puzzle folder
mkdir -p %{buildroot}%{_datadir}/desktop-directories
cat > %{buildroot}%{_datadir}/desktop-directories/%{name}.directory <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Simon Tatham's Puzzles
Icon=puzzle_section
Type=Directory
EOF

mkdir -p %{buildroot}%{_sysconfdir}/xdg/menus/applications-merged
cat > %{buildroot}%{_sysconfdir}/xdg/menus/applications-merged/%{name}.menu <<EOF
<!DOCTYPE Menu PUBLIC "-//freedesktop//DTD Menu 1.0//EN"
"http://www.freedesktop.org/standards/menu-spec/menu-1.0.dtd">
<Menu>
  <Name>Applications</Name>
  <Menu>
    <Name>Games</Name>
    <Menu>
      <Name>Puzzles</Name>
      <Menu>
        <Name>Simon Tatham's Puzzles</Name>
        <Directory>%{name}.directory</Directory>
        <Include>
          <Category>X-SGTatham-Puzzles</Category>
        </Include>
      </Menu>
    </Menu>
  </Menu>
</Menu>
EOF

%files
%doc HACKING puzzles.txt
%license LICENCE
%{_datadir}/applications/puzzle-*.desktop
%{_datadir}/desktop-directories/%{name}.directory
%{_gamesbindir}/puzzle-*
%{_iconsdir}/hicolor/*/apps/puzzle-*.png
%{_sysconfdir}/xdg/menus/applications-merged/%{name}.menu


%changelog
* Sat Feb 15 2020 daviddavid <daviddavid> 20191231-2.mga8
+ Revision: 1526369
- Version 20191231
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Apr 26 2019 akien <akien> 20190415-1.mga7
+ Revision: 1395463
- Version 20190415

* Sun Sep 23 2018 umeabot <umeabot> 20171210-2.mga7
+ Revision: 1301011
- Mageia 7 Mass Rebuild

* Sat Dec 30 2017 akien <akien> 20171210-1.mga7
+ Revision: 1187728
- Version 20171210

* Thu May 25 2017 akien <akien> 20170514-1.mga6
+ Revision: 1104589
- Version 20170514

* Fri Mar 17 2017 akien <akien> 20170314-1.mga6
+ Revision: 1093394
- Version 20170314

* Fri Dec 23 2016 akien <akien> 20161217-1.mga6
+ Revision: 1076551
- New snapshot 20161217

* Sun Oct 30 2016 akien <akien> 20161029-1.mga6
+ Revision: 1064223
- New snapshot

* Thu Jul 28 2016 akien <akien> 20160429-1.mga6
+ Revision: 1043832
- Version 20160429

* Sat Apr 16 2016 akien <akien> 20160410-1.mga6
+ Revision: 1003115
- Version 20160410

* Sun Jan 10 2016 akien <akien> 20160104-1.mga6
+ Revision: 921047
- Do not error on deprecated declarations, that's suicidal when using GTK+3
- New snapshot 20160104
- Build with GTK+ 3

* Fri Feb 06 2015 akien <akien> 20150118-1.mga5
+ Revision: 813633
- Version 20150118

* Wed Oct 15 2014 akien <akien> 10282-1.mga5
+ Revision: 756446
- Revision r10282
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 10196-2.mga5
+ Revision: 689129
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 akien <akien> 10196-1.mga5
+ Revision: 674135
- Version 10196

* Sat May 03 2014 akien <akien> 10180-2.mga5
+ Revision: 619787
- Fix desktop files exec path

* Sat May 03 2014 akien <akien> 10180-1.mga5
+ Revision: 619781
- importing source RPM based off the one from Fedora

